@@ -1,21 +1,26 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Config.pm $
-#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
 #   $Author: clonezone $
-# $Revision: 2018 $
+# $Revision: 2489 $
 ##############################################################################
 
 package Perl::Critic::Config;
 
+use 5.006001;
 use strict;
 use warnings;
-use Carp qw(confess);
+
 use English qw(-no_match_vars);
+use Readonly;
 
 use List::MoreUtils qw(any none apply);
 use Scalar::Util qw(blessed);
 
-use Perl::Critic::ConfigErrors;
+use Perl::Critic::Exception::AggregateConfiguration;
+use Perl::Critic::Exception::Configuration;
+use Perl::Critic::Exception::Configuration::Option::Global::ParameterValue;
+use Perl::Critic::Exception::Fatal::Internal qw{ throw_internal };
 use Perl::Critic::PolicyFactory;
 use Perl::Critic::Theme qw( $RULE_INVALID_CHARACTER_REGEX cook_rule );
 use Perl::Critic::UserProfile qw();
@@ -23,10 +28,15 @@ use Perl::Critic::Utils qw{
     :booleans :characters :severities :internal_lookup :classification
 };
 use Perl::Critic::Utils::Constants qw{ :profile_strictness };
+use Perl::Critic::Utils::DataConversion qw{ boolean_to_number dor };
 
 #-----------------------------------------------------------------------------
 
-our $VERSION = '1.080';
+our $VERSION = '1.088';
+
+#-----------------------------------------------------------------------------
+
+Readonly::Scalar my $SINGLE_POLICY_CONFIG_KEY => 'single-policy';
 
 #-----------------------------------------------------------------------------
 # Constructor
@@ -49,13 +59,13 @@ sub _init {
         $args{-severity} ||= $SEVERITY_LOWEST;
     }
 
-    my $errors = Perl::Critic::ConfigErrors->new();
+    my $errors = Perl::Critic::Exception::AggregateConfiguration->new();
 
     # Construct the UserProfile to get default options.
     my $profile_source  = $args{-profile}; #Can be file path or data struct
     my $profile =
         Perl::Critic::UserProfile->new( -profile => $profile_source );
-    my $defaults = $profile->defaults();
+    my $options_processor = $profile->options_processor();
     $self->{_profile} = $profile;
 
     $self->_validate_and_save_profile_strictness(
@@ -65,15 +75,15 @@ sub _init {
 
     # If given, these options should always have a true value.
     $self->_validate_and_save_regex(
-        'include', $args{-include}, $defaults->include(), $errors
+        'include', $args{-include}, $options_processor->include(), $errors
     );
     $self->_validate_and_save_regex(
-        'exclude', $args{-exclude}, $defaults->exclude(), $errors
+        'exclude', $args{-exclude}, $options_processor->exclude(), $errors
     );
     $self->_validate_and_save_regex(
-        'single-policy',
-        $args{'-single-policy'},
-        $defaults->single_policy(),
+        $SINGLE_POLICY_CONFIG_KEY,
+        $args{ qq/-$SINGLE_POLICY_CONFIG_KEY/ },
+        $options_processor->single_policy(),
         $errors,
     );
 
@@ -84,10 +94,11 @@ sub _init {
     # If given, these options can be true or false (but defined)
     # We normalize these to numeric values by multiplying them by 1;
     {
-        no warnings 'numeric'; ## no critic (ProhibitNoWarnings)
-        $self->{_force} = 1 * _dor( $args{-force}, $defaults->force() );
-        $self->{_only}  = 1 * _dor( $args{-only},  $defaults->only()  );
-        $self->{_color} = 1 * _dor( $args{-color}, $defaults->color() );
+        $self->{_force} = boolean_to_number( dor( $args{-force}, $options_processor->force() ) );
+        $self->{_only}  = boolean_to_number( dor( $args{-only},  $options_processor->only()  ) );
+        $self->{_color} = boolean_to_number( dor( $args{-color}, $options_processor->color() ) );
+        $self->{_criticism_fatal} =
+          boolean_to_number(dor( $args{'-criticism_fatal'}, $options_processor->criticism_fatal() ) );
     }
 
     $self->_validate_and_save_theme($args{-theme}, $errors);
@@ -101,18 +112,18 @@ sub _init {
         );
     $self->{_factory} = $factory;
 
-    if ( @{ $errors->messages() } ) {
-        die $errors;  ## no critic (RequireCarping)
-    }
-
     # Initialize internal storage for Policies
     $self->{_policies} = [];
 
     # "NONE" means don't load any policies
-    return $self if defined $profile_source and $profile_source eq 'NONE';
+    if ( not defined $profile_source or $profile_source ne 'NONE' ) {
+        # Heavy lifting here...
+        $self->_load_policies($errors);
+    }
 
-    # Heavy lifting here...
-    $self->_load_policies();
+    if ( $errors->has_exceptions() ) {
+        $errors->rethrow();
+    }
 
     return $self;
 }
@@ -123,8 +134,11 @@ sub add_policy {
 
     my ( $self, %args ) = @_;
 
-    my $policy  = $args{-policy}
-        or confess q{The -policy argument is required};
+    if ( not $args{-policy} ) {
+        throw_internal q{The -policy argument is required};
+    }
+
+    my $policy  = $args{-policy};
 
     # If the -policy is already a blessed object, then just add it directly.
     if ( blessed $policy ) {
@@ -140,7 +154,6 @@ sub add_policy {
         $factory->create_policy(-name=>$policy, -params=>$params);
     $self->_add_policy_if_enabled($policy_object);
 
-
     return $self;
 }
 
@@ -149,11 +162,12 @@ sub add_policy {
 sub _add_policy_if_enabled {
     my ( $self, $policy_object ) = @_;
 
-    my $parameters = $policy_object->__get_parameters()
-        or confess q{Policy was not set up properly because it doesn't have }
-                    . q{a value for its parameters attribute.};
+    my $config = $policy_object->__get_config()
+        or throw_internal
+            q{Policy was not set up properly because it doesn't have }
+                . q{a value for its config attribute.};
 
-    if ( $policy_object->initialize_if_enabled( $parameters ) ) {
+    if ( $policy_object->initialize_if_enabled( $config ) ) {
         push @{ $self->{_policies} }, $policy_object;
     }
 
@@ -164,9 +178,11 @@ sub _add_policy_if_enabled {
 
 sub _load_policies {
 
-    my ( $self ) = @_;
+    my ( $self, $errors ) = @_;
     my $factory  = $self->{_factory};
-    my @policies = $factory->create_all_policies();
+    my @policies = $factory->create_all_policies( $errors );
+
+    return if $errors->has_exceptions();
 
     for my $policy ( @policies ) {
 
@@ -196,7 +212,7 @@ sub _load_policies {
 
     # When using -single-policy, only one policy should ever be loaded.
     if ($self->single_policy() && scalar $self->policies() != 1) {
-        $self->_throw_single_policy_exception();
+        $self->_add_single_policy_exception_to($errors);
     }
 
     return;
@@ -267,24 +283,41 @@ sub _policy_is_single_policy {
 
 #-----------------------------------------------------------------------------
 
-sub _throw_single_policy_exception {
+sub _new_global_value_exception {
+    my ($self, @args) = @_;
 
-    my $self = shift;
+    return
+        Perl::Critic::Exception::Configuration::Option::Global::ParameterValue
+            ->new(@args);
+}
 
-    my $error_msg = $EMPTY;
+#-----------------------------------------------------------------------------
+
+sub _add_single_policy_exception_to {
+    my ($self, $errors) = @_;
+
+    my $message_suffix = $EMPTY;
     my $patterns = join q{", "}, $self->single_policy();
 
     if (scalar $self->policies() == 0) {
-        $error_msg =
-            qq{No policies matched any of "$patterns" (in combination with }
+        $message_suffix =
+            q{did not match any policies (in combination with }
                 . q{other policy restrictions).};
     }
     else {
-        $error_msg  = qq{Multiple policies matched "$patterns":\n\t};
-        $error_msg .= join qq{,\n\t}, apply { chomp } sort $self->policies();
+        $message_suffix  = qq{matched multiple policies:\n\t};
+        $message_suffix .= join qq{,\n\t}, apply { chomp } sort $self->policies();
     }
 
-    confess "$error_msg\n";
+    $errors->add_exception(
+        $self->_new_global_value_exception(
+            option_name     => $SINGLE_POLICY_CONFIG_KEY,
+            option_value    => $patterns,
+            message_suffix  => $message_suffix,
+        )
+    );
+
+    return;
 }
 
 #-----------------------------------------------------------------------------
@@ -321,20 +354,23 @@ sub _validate_and_save_regex {
 
     my $found_errors;
     foreach my $regex (@regexes) {
-        eval { my $test = qr/$regex/imx; };
-        if ($EVAL_ERROR) {
-            (my $cleaned_error = $EVAL_ERROR) =~
-                s/ [ ] at [ ] .* Config [.] pm [ ] line [ ] \d+ [.] \n? \z/./xms;
+        eval { my $test = qr/$regex/imx; }
+            or do {
+                my $cleaned_error = $EVAL_ERROR || '<unknown reason>';
+                $cleaned_error =~
+                    s/ [ ] at [ ] .* Config [.] pm [ ] line [ ] \d+ [.] \n? \z/./xms;
 
-            $errors->add_bad_option_message(
-                $option_name,
-                $regex,
-                $source,
-                qq{is not valid: $cleaned_error},
-            );
+                $errors->add_exception(
+                    $self->_new_global_value_exception(
+                        option_name     => $option_name,
+                        option_value    => $regex,
+                        source          => $source,
+                        message_suffix  => qq{is not valid: $cleaned_error},
+                    )
+                );
 
-            $found_errors = 1;
-        }
+                $found_errors = 1;
+            }
     }
 
     if (not $found_errors) {
@@ -365,17 +401,19 @@ sub _validate_and_save_profile_strictness {
 
         my $profile = $self->_profile();
         $source = $profile->source();
-        $profile_strictness = $profile->defaults()->profile_strictness();
+        $profile_strictness = $profile->options_processor()->profile_strictness();
     }
 
     if ( not $PROFILE_STRICTNESSES{$profile_strictness} ) {
-        $errors->add_bad_option_message(
-            $option_name,
-            $profile_strictness,
-            $source,
-            q{is not one of "}
-                . join ( q{", "}, (sort keys %PROFILE_STRICTNESSES) )
-                . q{".},
+        $errors->add_exception(
+            $self->_new_global_value_exception(
+                option_name     => $option_name,
+                option_value    => $profile_strictness,
+                source          => $source,
+                message_suffix  => q{is not one of "}
+                    . join ( q{", "}, (sort keys %PROFILE_STRICTNESSES) )
+                    . q{".},
+            )
         );
 
         $profile_strictness = $PROFILE_STRICTNESS_FATAL;
@@ -404,15 +442,21 @@ sub _validate_and_save_verbosity {
 
         my $profile = $self->_profile();
         $source = $profile->source();
-        $verbosity = $profile->defaults()->verbose();
+        $verbosity = $profile->options_processor()->verbose();
     }
 
-    if ( is_integer($verbosity) and not is_valid_numeric_verbosity($verbosity) ) {
-        $errors->add_bad_option_message(
-            $option_name,
-            $verbosity,
-            $source,
-            'is not the number of one of the pre-defined verbosity formats.',
+    if (
+            is_integer($verbosity)
+        and not is_valid_numeric_verbosity($verbosity)
+    ) {
+        $errors->add_exception(
+            $self->_new_global_value_exception(
+                option_name     => $option_name,
+                option_value    => $verbosity,
+                source          => $source,
+                message_suffix  =>
+                    'is not the number of one of the pre-defined verbosity formats.',
+            )
         );
     }
     else {
@@ -440,7 +484,7 @@ sub _validate_and_save_severity {
 
         my $profile = $self->_profile();
         $source = $profile->source();
-        $severity = $profile->defaults()->severity();
+        $severity = $profile->options_processor()->severity();
     }
 
     if ( is_integer($severity) ) {
@@ -450,22 +494,28 @@ sub _validate_and_save_severity {
             $self->{_severity} = $severity;
         }
         else {
-            $errors->add_bad_option_message(
-                $option_name,
-                $severity,
-                $source,
-                "is not between $SEVERITY_LOWEST (low) and $SEVERITY_HIGHEST (high).",
+            $errors->add_exception(
+                $self->_new_global_value_exception(
+                    option_name     => $option_name,
+                    option_value    => $severity,
+                    source          => $source,
+                    message_suffix  =>
+                        "is not between $SEVERITY_LOWEST (low) and $SEVERITY_HIGHEST (high).",
+                )
             );
         }
     }
     elsif ( not any { $_ eq lc $severity } @SEVERITY_NAMES ) {
-        $errors->add_bad_option_message(
-            $option_name,
-            $severity,
-            $source,
-            q{is not one of the valid severity names: "}
-                . join (q{", "}, @SEVERITY_NAMES)
-                . q{".},
+        $errors->add_exception(
+            $self->_new_global_value_exception(
+                option_name     => $option_name,
+                option_value    => $severity,
+                source          => $source,
+                message_suffix  =>
+                    q{is not one of the valid severity names: "}
+                        . join (q{", "}, @SEVERITY_NAMES)
+                        . q{".},
+            )
         );
     }
     else {
@@ -493,18 +543,20 @@ sub _validate_and_save_top {
 
         my $profile = $self->_profile();
         $source = $profile->source();
-        $top = $profile->defaults()->top();
+        $top = $profile->options_processor()->top();
     }
 
     if ( is_integer($top) and $top >= 0 ) {
         $self->{_top} = $top;
     }
     else {
-        $errors->add_bad_option_message(
-            $option_name,
-            $top,
-            $source,
-            q{is not a non-negative integer.},
+        $errors->add_exception(
+            $self->_new_global_value_exception(
+                option_name     => $option_name,
+                option_value    => $top,
+                source          => $source,
+                message_suffix  => q{is not a non-negative integer.},
+            )
         );
     }
 
@@ -529,51 +581,54 @@ sub _validate_and_save_theme {
 
         my $profile = $self->_profile();
         $source = $profile->source();
-        $theme_rule = $profile->defaults()->theme();
+        $theme_rule = $profile->options_processor()->theme();
     }
 
     if ( $theme_rule =~ m/$RULE_INVALID_CHARACTER_REGEX/xms ) {
         my $bad_character = $1;
 
-        $errors->add_bad_option_message(
-            $option_name,
-            $theme_rule,
-            $source,
-            qq{contains an illegal character ("$bad_character").},
+        $errors->add_exception(
+            $self->_new_global_value_exception(
+                option_name     => $option_name,
+                option_value    => $theme_rule,
+                source          => $source,
+                message_suffix  =>
+                    qq{contains an illegal character ("$bad_character").},
+            )
         );
     }
     else {
         my $rule_as_code = cook_rule($theme_rule);
         $rule_as_code =~ s/ [\w\d]+ / 1 /gxms;
 
-        # eval of an empty string does not reset $@ in Perl 5.6
+        # eval of an empty string does not reset $@ in Perl 5.6.
         local $EVAL_ERROR = $EMPTY;
-        eval $rule_as_code;  ## no critic (ProhibitStringyEval)
+        eval $rule_as_code; ## no critic (ProhibitStringyEval, RequireCheckingReturnValueOfEval)
 
         if ($EVAL_ERROR) {
-            $errors->add_bad_option_message(
-                $option_name,
-                $theme_rule,
-                $source,
-                q{is not syntactically valid.},
+            $errors->add_exception(
+                $self->_new_global_value_exception(
+                    option_name     => $option_name,
+                    option_value    => $theme_rule,
+                    source          => $source,
+                    message_suffix  => q{is not syntactically valid.},
+                )
             );
         }
         else {
-            $self->{_theme} = Perl::Critic::Theme->new( -rule => $theme_rule );
+            eval {
+                $self->{_theme} =
+                    Perl::Critic::Theme->new( -rule => $theme_rule );
+            }
+                or do {
+                    $errors->add_exception_or_rethrow( $EVAL_ERROR );
+                };
         }
     }
 
     return;
 }
 
-#-----------------------------------------------------------------------------
-
-sub _dor {
-    #The defined-or //
-    my ($this, $that) = @_;
-    return defined $this ? $this : $that;
-}
-
 #-----------------------------------------------------------------------------
 # Begin ACCESSSOR methods
 
@@ -668,6 +723,13 @@ sub color {
 
 #-----------------------------------------------------------------------------
 
+sub criticism_fatal {
+    my $self = shift;
+    return $self->{_criticism_fatal};
+}
+
+#-----------------------------------------------------------------------------
+
 sub site_policy_names {
     return Perl::Critic::PolicyFactory::site_policy_names();
 }
@@ -684,7 +746,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Config - The Perl::Critic user-preferences, combined from any profile file and command-line parameters.
+Perl::Critic::Config - The final derived Perl::Critic configuration, combined from any profile file and command-line parameters.
 
 =head1 DESCRIPTION
 
@@ -699,7 +761,7 @@ constructor will do it for you.
 
 =over 8
 
-=item C<< new( [ -profile => $FILE, -severity => $N, -theme => $string, -include => \@PATTERNS, -exclude => \@PATTERNS, -single-policy => $PATTERN, -top => $N, -only => $B, -profile-strictness => $PROFILE_STRICTNESS_{WARN|FATAL|QUIET}, -force => $B, -verbose => $N, -color => $B ] ) >>
+=item C<< new( [ -profile => $FILE, -severity => $N, -theme => $string, -include => \@PATTERNS, -exclude => \@PATTERNS, -single-policy => $PATTERN, -top => $N, -only => $B, -profile-strictness => $PROFILE_STRICTNESS_{WARN|FATAL|QUIET}, -force => $B, -verbose => $N, -color => $B, -criticism-fatal => $B] ) >>
 
 =item C<< new() >>
 
@@ -788,6 +850,11 @@ explanation of format specifications.
 B<-color> is not used by Perl::Critic but is provided for the benefit
 of L<perlcritic>.
 
+B<-criticism-fatal> is not used by Perl::Critic but is provided for the benefit
+of L<criticism>.
+
+
+
 =back
 
 =head1 METHODS
@@ -861,6 +928,10 @@ Returns the value of the C<-verbose> attribute for this Config.
 
 Returns the value of the C<-color> attribute for this Config.
 
+=item C< criticism_fatal() >
+
+Returns the value of the C<-criticsm-fatal> attribute for this Config.
+
 =back
 
 =head1 SUBROUTINES
@@ -1064,13 +1135,18 @@ then it is equivalent to the set of all Policies.  A theme name that doesn't
 exist is equivalent to an empty set.  Please See
 L<http://en.wikipedia.org/wiki/Set> for a discussion on set theory.
 
+=head1 SEE ALSO
+
+L<Perl::Critic::OptionsProcessor>, L<Perl::Critic::UserProfile>
+
+
 =head1 AUTHOR
 
 Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2007 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -1086,4 +1162,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
