@@ -1,12 +1,13 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/ControlStructures/ProhibitPostfixControls.pm $
-#     $Date: 2008-03-08 10:09:46 -0600 (Sat, 08 Mar 2008) $
+#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
 #   $Author: clonezone $
-# $Revision: 2163 $
+# $Revision: 2489 $
 ##############################################################################
 
 package Perl::Critic::Policy::ControlStructures::ProhibitPostfixControls;
 
+use 5.006001;
 use strict;
 use warnings;
 use Readonly;
@@ -14,7 +15,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :characters :severities :data_conversion :classification };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.082';
+our $VERSION = '1.088';
 
 #-----------------------------------------------------------------------------
 
@@ -100,16 +101,21 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::ControlStructures::ProhibitPostfixControls
+Perl::Critic::Policy::ControlStructures::ProhibitPostfixControls - Write C<if($condition){ do_something() }> instead of C<do_something() if $condition>.
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic> distribution.
+
 
 =head1 DESCRIPTION
 
 Conway discourages using postfix control structures (C<if>, C<for>,
-C<unless>, C<until>, C<while>).  The C<unless> and C<until> controls
-are particularly evil because they lead to double-negatives that are
-hard to comprehend.  The only tolerable usage of a postfix C<if> is
-when it follows a loop break such as C<last>, C<next>, C<redo>, or
-C<continue>.
+C<unless>, C<until>, C<while>) because they hide control flow.  The
+C<unless> and C<until> controls are particularly evil because they
+lead to double-negatives that are hard to comprehend.  The only
+tolerable usage of a postfix C<if> is when it follows a loop break
+such as C<last>, C<next>, C<redo>, or C<continue>.
 
   do_something() if $condition;         #not ok
   if($condition){ do_something() }      #ok
@@ -135,10 +141,10 @@ C<continue>.
 
 =head1 CONFIGURATION
 
-A set of constructs to be ignored by this policy can specified by giving a
-value for 'allow' of a string of space-delimited keywords: C<if>, C<for>,
-C<unless>, C<until>, and/or C<while>.  An example of specifying allowed
-flow-control structures in a F<.perlcriticrc> file:
+A set of constructs to be ignored by this policy can specified by
+giving a value for 'allow' of a string of space-delimited keywords:
+C<if>, C<for>, C<unless>, C<until>, and/or C<while>.  An example of
+specifying allowed flow-control structures in a F<.perlcriticrc> file:
 
  [ControlStructures::ProhibitPostfixControls]
  allow = for if until
@@ -182,4 +188,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
