@@ -1,12 +1,13 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/RegularExpressions/RequireExtendedFormatting.pm $
-#     $Date: 2008-03-08 10:09:46 -0600 (Sat, 08 Mar 2008) $
+#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
 #   $Author: clonezone $
-# $Revision: 2163 $
+# $Revision: 2489 $
 ##############################################################################
 
 package Perl::Critic::Policy::RegularExpressions::RequireExtendedFormatting;
 
+use 5.006001;
 use strict;
 use warnings;
 use Readonly;
@@ -15,7 +16,7 @@ use Perl::Critic::Utils qw{ :severities };
 use Perl::Critic::Utils::PPIRegexp qw{ &get_modifiers };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.082';
+our $VERSION = '1.088';
 
 #-----------------------------------------------------------------------------
 
@@ -53,7 +54,12 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::RegularExpressions::RequireExtendedFormatting
+Perl::Critic::Policy::RegularExpressions::RequireExtendedFormatting - Always use the C</x> modifier with regular expressions.
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic> distribution.
+
 
 =head1 DESCRIPTION
 
@@ -75,6 +81,12 @@ comments into the pattern, thus making them much more readable.
        '           # a closing single quote
      }x;
 
+
+=head1 CONFIGURATION
+
+This Policy is not configurable except for the standard options.
+
+
 =head1 NOTES
 
 For common regular expressions like e-mail addresses, phone numbers,
@@ -106,4 +118,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
