@@ -1,12 +1,13 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/Variables/ProhibitMatchVars.pm $
-#     $Date: 2008-03-08 10:09:46 -0600 (Sat, 08 Mar 2008) $
+#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
 #   $Author: clonezone $
-# $Revision: 2163 $
+# $Revision: 2489 $
 ##############################################################################
 
 package Perl::Critic::Policy::Variables::ProhibitMatchVars;
 
+use 5.006001;
 use strict;
 use warnings;
 use Readonly;
@@ -14,7 +15,7 @@ use Readonly;
 use Perl::Critic::Utils qw{ :severities :data_conversion };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.082';
+our $VERSION = '1.088';
 
 #-----------------------------------------------------------------------------
 
@@ -49,7 +50,11 @@ sub _is_use_english {
     $elem->isa('PPI::Statement::Include') || return;
     $elem->type() eq 'use' || return;
     $elem->module() eq 'English' || return;
-    return 1 if ($elem =~ m/\A use \s+ English \s* ;\z/xms); # Bare, lacking -no_match_vars
+
+    # Bare, lacking -no_match_vars.  Now handled by
+    # Modules::RequireNoMatchVarsWithUseEnglish.
+    return 0 if ($elem =~ m/\A use \s+ English \s* ;\z/xms);
+
     return 1 if ($elem =~ m/\$(?:PRE|POST|)MATCH/xms);
     return;  # either "-no_match_vars" or a specific list
 }
@@ -70,17 +75,32 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Variables::ProhibitMatchVars
+Perl::Critic::Policy::Variables::ProhibitMatchVars - Avoid C<$`>, C<$&>, C<$'> and their English equivalents.
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic> distribution.
+
 
 =head1 DESCRIPTION
 
 Using the "match variables" C<$`>, C<$&>, and/or C<$'> can
 significantly degrade the performance of a program.  This policy
-forbids using them or their English equivalents.  It also forbids
-plain C<use English;> so you should instead employ C<use English
-'-no_match_vars';> which avoids the match variables.  See B<perldoc
+forbids using them or their English equivalents.  See B<perldoc
 English> or PBP page 82 for more information.
 
+It used to forbid plain C<use English;> because it ends up causing the
+performance side-effects of the match variables.  However, the message
+emitted for that situation was not at all clear and there is now
+L<Perl::Critic::Policy::Modules::RequireNoMatchVarsWithUseEnglish>,
+which addresses this situation directly.
+
+
+=head1 CONFIGURATION
+
+This Policy is not configurable except for the standard options.
+
+
 =head1 AUTHOR
 
 Chris Dolan <cdolan@cpan.org>
@@ -102,4 +122,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
