@@ -1,12 +1,13 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Policy/Variables/ProhibitPerl4PackageNames.pm $
-#     $Date: 2008-03-08 10:09:46 -0600 (Sat, 08 Mar 2008) $
+#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
 #   $Author: clonezone $
-# $Revision: 2163 $
+# $Revision: 2489 $
 ##############################################################################
 
 package Perl::Critic::Policy::Variables::ProhibitPerl4PackageNames;
 
+use 5.006001;
 use strict;
 use warnings;
 use Readonly;
@@ -14,12 +15,12 @@ use Readonly;
 use Perl::Critic::Utils qw{ :characters :severities :classification };
 use base 'Perl::Critic::Policy';
 
-our $VERSION = '1.082';
+our $VERSION = '1.088';
 
 #-----------------------------------------------------------------------------
 
 Readonly::Scalar my $EXPL =>
-    q{Use double colon (::) to separate package name components instead of single quotes (').};
+    q{Use double colon (::) to separate package name components instead of single quotes (')};
 
 #-----------------------------------------------------------------------------
 
@@ -35,7 +36,12 @@ sub violates {
     my $content = $elem->content();
 
     if ( (index $content, $QUOTE) < 0 ) {
-                return;
+        return;
+    }
+
+    if ( $content =~ m< \A [\$@%&*] ' \z >xms ) {
+        # We've found $POSTMATCH.
+        return;
     }
 
     if ( $elem->isa('PPI::Token::Word') && is_hash_key($elem) ) {
@@ -62,7 +68,12 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Policy::Variables::ProhibitPerl4PackageNames
+Perl::Critic::Policy::Variables::ProhibitPerl4PackageNames - Use double colon (::) to separate package name components instead of single quotes (').
+
+=head1 AFFILIATION
+
+This Policy is part of the core L<Perl::Critic> distribution.
+
 
 =head1 DESCRIPTION
 
@@ -76,6 +87,12 @@ So, unless you're trying to obfuscate your code, don't use them.
   package Foo::Bar::Baz;    #ok
   package Foo'Bar'Baz;      #not ok
 
+
+=head1 CONFIGURATION
+
+This Policy is not configurable except for the standard options.
+
+
 =head1 SEE ALSO
 
 L<perlmod>
@@ -101,4 +118,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
