@@ -1,8 +1,8 @@
 ##############################################################################
 #      $URL: http://perlcritic.tigris.org/svn/perlcritic/trunk/Perl-Critic/lib/Perl/Critic/Utils.pm $
-#     $Date: 2007-11-11 21:48:21 -0600 (Sun, 11 Nov 2007) $
+#     $Date: 2008-07-03 10:19:10 -0500 (Thu, 03 Jul 2008) $
 #   $Author: clonezone $
-# $Revision: 2018 $
+# $Revision: 2489 $
 ##############################################################################
 
 # NOTE: This module is way too large.  Please think about adding new
@@ -10,6 +10,7 @@
 
 package Perl::Critic::Utils;
 
+use 5.006001;
 use strict;
 use warnings;
 use Readonly;
@@ -24,7 +25,7 @@ use Perl::Critic::Utils::PPI qw< is_ppi_expression_or_generic_statement >;
 
 use base 'Exporter';
 
-our $VERSION = '1.080';
+our $VERSION = '1.088';
 
 #-----------------------------------------------------------------------------
 # Exportable symbols here.
@@ -295,10 +296,21 @@ sub is_perl_bareword {
 
 #-----------------------------------------------------------------------------
 
-Readonly::Array my @GLOBALS_WITHOUT_SIGILS =>
-    map { substr $_, 1 }  @B::Keywords::Arrays,
-                          @B::Keywords::Hashes,
-                          @B::Keywords::Scalars;
+sub _build_globals_without_sigils {
+    my @globals = map { substr $_, 1 }  @B::Keywords::Arrays,
+                                        @B::Keywords::Hashes,
+                                        @B::Keywords::Scalars;
+
+    # Not all of these have sigils
+    foreach my $filehandle (@B::Keywords::Filehandles) {
+        (my $stripped = $filehandle) =~ s< \A [*] ><>xms;
+        push @globals, $stripped;
+    }
+
+    return @globals;
+}
+
+Readonly::Array my @GLOBALS_WITHOUT_SIGILS => _build_globals_without_sigils();
 
 Readonly::Hash my %GLOBALS => hashify( @GLOBALS_WITHOUT_SIGILS );
 
@@ -306,7 +318,7 @@ sub is_perl_global {
     my $elem = shift;
     return if !$elem;
     my $var_name = "$elem"; #Convert Token::Symbol to string
-    $var_name =~ s{\A [\$@%] }{}mx;  #Chop off the sigil
+    $var_name =~ s{\A [\$@%*] }{}mx;  #Chop off the sigil
     return exists $GLOBALS{ $var_name };
 }
 
@@ -1018,7 +1030,7 @@ sub _is_perl {
     my $first = <$fh>;
     close $fh or throw_generic "unable to close $file: $!";
 
-    return 1 if defined $first && ( $first =~ m{ \A [#]![ ]*\S*perl }mx );
+    return 1 if defined $first && ( $first =~ m{ \A [#]!.*perl }mx );
     return;
 }
 
@@ -1026,15 +1038,16 @@ sub _is_perl {
 
 sub shebang_line {
     my $doc = shift;
-    my $first_comment = $doc->find_first('PPI::Token::Comment');
-    return if !$first_comment;
-    my $location = $first_comment->location();
+    my $first_element = $doc->first_element();
+    return if not $first_element;
+    return if not $first_element->isa('PPI::Token::Comment');
+    my $location = $first_element->location();
     return if !$location;
     # The shebang must be the first two characters in the file, according to
     # http://en.wikipedia.org/wiki/Shebang_(Unix)
     return if $location->[0] != 1; # line number
     return if $location->[1] != 1; # column number
-    my $shebang = $first_comment->content;
+    my $shebang = $first_element->content;
     return if $shebang !~ m{ \A [#]! }mx;
     return $shebang;
 }
@@ -1133,7 +1146,7 @@ __END__
 
 =head1 NAME
 
-Perl::Critic::Utils - Utility subs and vars for Perl::Critic
+Perl::Critic::Utils - General utility subroutines and constants for Perl::Critic and derivative distributions.
 
 =head1 DESCRIPTION
 
@@ -1332,9 +1345,9 @@ which returns C<($x + $y)> as a L<PPI::Structure::List> instance.
 Given a L<PPI::Element> that is presumed to be a function call (which is
 usually a L<PPI::Token::Word>), splits the argument expressions into arrays of
 tokens.  Returns a list containing references to each of those arrays.  This
-is useful because parens are optional when calling a function, and PPI parses
-them very differently.  So this method is a poor-man's parse tree of PPI
-nodes.  It's not bullet-proof because it doesn't respect precedence.  In
+is useful because parentheses are optional when calling a function, and PPI
+parses them very differently.  So this method is a poor-man's parse tree of
+PPI nodes.  It's not bullet-proof because it doesn't respect precedence.  In
 general, I don't like the way this function works, so don't count on it to be
 stable (or even present).
 
@@ -1626,7 +1639,7 @@ Jeffrey Ryan Thalhammer <thaljef@cpan.org>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2007 Jeffrey Ryan Thalhammer.  All rights reserved.
+Copyright (c) 2005-2008 Jeffrey Ryan Thalhammer.  All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.  The full text of this license
@@ -1641,4 +1654,4 @@ can be found in the LICENSE file included with this module.
 #   indent-tabs-mode: nil
 #   c-indentation-style: bsd
 # End:
-# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab :
+# ex: set ts=8 sts=4 sw=4 tw=78 ft=perl expandtab shiftround :
